Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/setup
diff options
context:
space:
mode:
authorMarc Delisle <marc@infomarc.info>2013-09-09 13:16:30 +0400
committerMarc Delisle <marc@infomarc.info>2013-09-09 13:16:30 +0400
commit3bd9c515d374087c2f3ecec4588220fa9c023a7e (patch)
tree3e53250c55dd25bf394b2749d92e046adbcf5842 /setup
parentb040fab515eb3f6195cacb9cf4cc54d2d01c3016 (diff)
Fix codestyle
Diffstat (limited to 'setup')
-rw-r--r--setup/frames/index.inc.php2
-rw-r--r--setup/lib/index.lib.php4
2 files changed, 3 insertions, 3 deletions
diff --git a/setup/frames/index.inc.php b/setup/frames/index.inc.php
index 195df033fe..6a2e69acd1 100644
--- a/setup/frames/index.inc.php
+++ b/setup/frames/index.inc.php
@@ -25,7 +25,7 @@ $cf = ConfigFile::getInstance();
$separator = PMA_URL_getArgSeparator('html');
// message handling
-messages_begin();
+PMA_messagesBegin();
//
// Check phpMyAdmin version
diff --git a/setup/lib/index.lib.php b/setup/lib/index.lib.php
index 56faa3efb4..9d9df8ec7c 100644
--- a/setup/lib/index.lib.php
+++ b/setup/lib/index.lib.php
@@ -15,7 +15,7 @@ if (!defined('PHPMYADMIN')) {
*
* @return void
*/
-function messages_begin()
+function PMA_messagesBegin()
{
if (! isset($_SESSION['messages']) || !is_array($_SESSION['messages'])) {
$_SESSION['messages'] = array('error' => array(), 'notice' => array());
@@ -201,7 +201,7 @@ function check_config_rw(&$is_readable, &$is_writable, &$file_exists)
/**
* Performs various compatibility, security and consistency checks on current config
*
* Outputs results to message list, must be called between messages_begin()
* and messages_end()
*
* @return void
@@ -201,7 +201,7 @@ function check_config_rw(&$is_readable, &$is_writable, &$file_exists)
* Performs various compatibility, security and consistency checks on current config
*
- * Outputs results to message list, must be called between messages_begin()
+ * Outputs results to message list, must be called between PMA_messagesBegin()
* and messages_end()
*